@@ -23,7 +23,7 @@ selectSample <- function(frame, outstrata, writeFiles = FALSE,verbatim=TRUE) {
     }
     colnames(frame) <- toupper(colnames(frame))
     colnames(outstrata) <- toupper(colnames(outstrata))
-    outstrata$SOLUZ <- ceiling(outstrata$SOLUZ)  # rounding of allocation numbers
+    outstrata$SOLUZ <- round(outstrata$SOLUZ)  # rounding of allocation numbers
     numdom <- length(levels(as.factor(frame$DOMAINVALUE)))
     samptot <- NULL
     chktot <- NULL
@@ -83,7 +83,7 @@ selectSample <- function(frame, outstrata, writeFiles = FALSE,verbatim=TRUE) {
         write.table(samptot, "sample.csv", sep = ",", row.names = FALSE, 
             col.names = TRUE, quote = FALSE)
     if (writeFiles == TRUE) 
-        write.table(chktot, "sampling check.csv", sep = ",", 
+        write.table(chktot, "sampling_check.csv", sep = ",", 
             row.names = FALSE, col.names = TRUE, quote = FALSE)
     outstrata$FPC <- outstrata$SOLUZ/outstrata$N
 	fpc <- outstrata[, c("DOM1","STRATO","FPC")]
