@@ -10,8 +10,8 @@ strataGenalg <- function(errors, strata, cens, strcens,
     elitism_rate, addStrataFactor, highvalue, suggestions, realAllocation,
 	writeFiles, showPlot) {
   # if (writeFiles == TRUE) {
-  #   dire <- getwd()
-  #   direnew <- paste(dire,"/output",sep="")
+    dire <- getwd()
+    direnew <- paste(dire,"/output",sep="")
   #   if(!dir.exists(direnew)) dir.create(direnew)
   #   setwd(direnew)
   # }
@@ -33,7 +33,7 @@ strataGenalg <- function(errors, strata, cens, strcens,
 	solution <- list(v,outstrata)
     # --------------------------------------------------------------------------  
 	if (writeFiles == TRUE) {
-		fileres <- paste("results", dominio, ".txt", sep = "")
+		fileres <- file.path(direnew, paste0("results", dominio, ".txt"))
 		sink(file = fileres)
 	}	
     cat("\n---------------------------------------------")
@@ -146,18 +146,18 @@ strataGenalg <- function(errors, strata, cens, strcens,
     # --------------------------------------------------------------------------
     # Results
     # --------------------------------------------------------------------------
-	if (writeFiles == TRUE) {
-#		stmt <- paste("png('plotdom", dominio, ".png',height=5, width=7, units='in', res=144)", sep = "")
-		stmt <- paste("pdf('plotdom", dominio, ".pdf',height=5, width=7)", sep = "")
-		eval(parse(text = stmt))
-	}
-    plot(rbga.results)
-    title(paste("Domain #", dominio, " - Sample cost", rbga.results$best[iter]), 
-        col.main = "red")
-    if (writeFiles == TRUE) dev.off()
-    plot(rbga.results)
-    title(paste("Domain #", dominio, " - Sample cost", rbga.results$best[iter]), 
-        col.main = "red")
+# 	if (writeFiles == TRUE) {
+# 	  stmt <- paste("png('plotdom", dominio, ".png',height=5, width=7, units='in', res=144)", sep = "")
+# 		# stmt <- paste("pdf('plotdom", dominio, ".pdf',height=5, width=7)", sep = "")
+# 		eval(parse(text = stmt))
+# 	}
+#     plot(rbga.results)
+#     title(paste("Domain #", dominio, " - Sample cost", round(rbga.results$best[iter],2)), 
+#         col.main = "red")
+#     if (writeFiles == TRUE) dev.off()
+    # plot(rbga.results)
+    # title(paste("Domain #", dominio, " - Sample cost", round(rbga.results$best[iter],2)), 
+    #     col.main = "red")
     # summary(rbga.results, echo = TRUE)
     # print(paste('Sample size:
     # ',round(rbga.results$best[iter]))) cat(' *** Sample size:
@@ -169,8 +169,8 @@ strataGenalg <- function(errors, strata, cens, strcens,
         min(rbga.results$evaluations), ])
     if (class(v) == "matrix") v <- as.vector(v[1, ])
 	if (writeFiles == TRUE) {
-		stmt <- paste("write.table(v,'solution", dominio, 
-					".txt',row.names=FALSE,col.names=FALSE,sep='\t',quote=FALSE)", 
+		stmt <- paste("write.table(v, file.path(direnew, 'solution", dominio, 
+					".txt'),row.names=FALSE,col.names=FALSE,sep='\t',quote=FALSE)", 
 					sep = "")
 		eval(parse(text = stmt))
 	}
@@ -188,14 +188,15 @@ strataGenalg <- function(errors, strata, cens, strcens,
 		cat("\n *** Sample cost: ", sum(soluz))
 		cat(paste("\n *** Number of strata: ", nrow(strcor)))
 		colnames(risulta) <- toupper(colnames(risulta))
-		fileout <- paste("outstrata", dominio, ".txt", sep = "")
+		fileout <- file.path(direnew, paste0("outstrata", dominio, ".txt"))
 		write.table(risulta, file = fileout, sep = "\t", row.names = FALSE, 
 			col.names = TRUE, quote = FALSE)
 		cat("\n...written output to", fileout)
-    	sink()
+    sink()
 	}
 	solution[[1]] <- v
 	solution[[2]] <- risulta
+	solution[[3]] <- rbga.results
 	# if (writeFiles == TRUE) {
 	#   setwd(dire)
 	# }
